@@ -21,7 +21,7 @@ from hcloud.certificates import (
     ],
 )
 def test_eq(value):
-    assert value == value
+    assert value.__eq__(value)
 
 
 class TestCertificate:
